==> haskell-text-builder-0.6.7-257-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-builder
version:              0.6.7
visibility:           public
id:                   text-builder-0.6.7-3TaEpvMnwH08UxjRINbAzz
key:                  text-builder-0.6.7-3TaEpvMnwH08UxjRINbAzz
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/text-builder
synopsis:             An efficient strict text builder
category:             Text
abi:                  622d7fb18d36551174a77ca199ff4f3e
exposed:              True
exposed-modules:      Text.Builder
hidden-modules:       Text.Builder.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-builder-0.6.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-builder-0.6.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-builder-0.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-builder
hs-libraries:         HStext-builder-0.6.7-3TaEpvMnwH08UxjRINbAzz
depends:
    base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2
    text-builder-dev-0.3.3.2-1N0fgV1waYAFbmkLPludAC

haddock-interfaces:
    /usr/share/doc/haskell-text-builder/html/text-builder.haddock

haddock-html:         /usr/share/doc/haskell-text-builder/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-builder-0.6.7-258-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-builder
version:              0.6.7
visibility:           public
id:                   text-builder-0.6.7-3jDvFlNVcBEAXmUDb59AwB
key:                  text-builder-0.6.7-3jDvFlNVcBEAXmUDb59AwB
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/text-builder
synopsis:             An efficient strict text builder
category:             Text
abi:                  a2eb6cbe35d64dabd10743cd1a53a852
exposed:              True
exposed-modules:      Text.Builder
hidden-modules:       Text.Builder.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-builder-0.6.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-builder-0.6.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-builder-0.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-builder
hs-libraries:         HStext-builder-0.6.7-3jDvFlNVcBEAXmUDb59AwB
depends:
    base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2
    text-builder-dev-0.3.3.2-3aIctu3FE2WAvVBWMGfT3L

haddock-interfaces:
    /usr/share/doc/haskell-text-builder/html/text-builder.haddock

haddock-html:         /usr/share/doc/haskell-text-builder/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
